@@ -2,6 +2,3 @@ from justhacking import letsbegin
 
 def main():
   letsbegin()
-
-if __name__ == '__main__':
-  main()
\ No newline at end of file
